package de.intevation.flys.importer;

import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;

import de.intevation.flys.model.GrainFraction;
import de.intevation.flys.model.Unit;


public class ImportGrainFraction {

    private static final Logger log =
        Logger.getLogger(ImportGrainFraction.class);

    private String name;

    private Double lower;
    private Double upper;

    private ImportUnit unit;

    private GrainFraction peer;


    public ImportGrainFraction(
        String     name,
        Double     lower,
        Double     upper,
        ImportUnit unit
    ) {
        this.name  = name;
        this.lower = lower;
        this.upper = upper;
        this.unit  = unit;
    }


    public void storeDependencies() {
        log.debug("store dependencies");

        getPeer();
    }


    public GrainFraction getPeer() {
        log.debug("get peer");

        Unit u = unit != null ? unit.getPeer() : null;

        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();
            Query query = session.createQuery(
                "from GrainFraction where " +
                "   name=:name and " +
                "   lower=:lower and " +
                "   upper=:upper and " +
                "   unit=:unit"
            );

            query.setParameter("name", name);
            query.setParameter("lower", lower);
            query.setParameter("upper", upper);
            query.setParameter("unit", u);

            List<GrainFraction> fractions = query.list();
            if (fractions.isEmpty()) {
                log.info("create new GrainFraction");

                peer = new GrainFraction(name, lower, upper, u);
                session.save(peer);
            }
            else {
                peer = fractions.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
